@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2020 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Transport.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Transport::SMTP;
 use vars '$VERSION';
-$VERSION = '3.001';
+$VERSION = '3.005';
 
 use base 'Mail::Transport::Send';
 
+use strict;
+use warnings;
+
 use Net::SMTP;
 
 
@@ -31,7 +35,7 @@ sub init($)
     $self->SUPER::init($args) or return;
 
     my $helo = $args->{helo}
-      || eval { require Net::Config; $Net::Config::inet_domain }
+      || eval { require Net::Config; $Net::Config::NetConfig{inet_domain} }
       || eval { require Net::Domain; Net::Domain::hostfqdn() };
 
     $self->{MTS_net_smtp_opts} =
@@ -56,13 +60,12 @@ sub trySend($@)
     my $from = $args{from} || $self->{MTS_from} || $message->sender || '<>';
     $from = $from->address if ref $from && $from->isa('Mail::Address');
 
-    # Who are the destinations.
-    if(defined $args{To})
-    {   $self->log(WARNING =>
-   "Use option `to' to overrule the destination: `To' would refer to a field");
-    }
+    # Which are the destinations.
+    ! defined $args{To}
+        or $self->log(WARNING =>
+   "Use option `to' to overrule the destination: `To' refers to a field");
 
-    my @to = map {$_->address} $self->destinations($message, $args{to});
+    my @to = map $_->address, $self->destinations($message, $args{to});
 
     unless(@to)
     {   $self->log(NOTICE =>
@@ -71,9 +74,9 @@ sub trySend($@)
     }
 
     # Prepare the header
-    my @header;
+    my @headers;
     require IO::Lines;
-    my $lines = IO::Lines->new(\@header);
+    my $lines = IO::Lines->new(\@headers);
     $message->head->printUndisclosed($lines);
 
     #
@@ -96,18 +99,19 @@ sub trySend($@)
               return (0, $server->code, $server->message,"To $_",$server->quit);
         }
 
-        $server->data;
-        $server->datasend($_) foreach @header;
         my $bodydata = $message->body->file;
 
-        if(ref $bodydata eq 'GLOB') { $server->datasend($_) while <$bodydata> }
-        else    { while(my $l = $bodydata->getline) { $server->datasend($l) } }
+        $server->data;
+        $server->datasend(\@headers);
+        $server->datasend( [ ref $bodydata eq 'GLOB' ? <$bodydata> : $bodydata->getlines ] );
+        $server->dataend
+            or return (0, $server->code, $server->message,'DATA',$server->quit);
 
-        return (0, $server->code, $server->message, 'DATA', $server->quit)
-            unless $server->dataend;
+        my $accept = ($server->message)[-1];
+        chomp $accept;
 
-        return ($server->quit, $server->code, $server->message, 'QUIT',
-                $server->code);
+		my $rc     = $server->quit;
+        return ($rc, $server->code, $server->message, 'QUIT', $rc, $accept);
     }
 
     # in SCALAR context
@@ -126,12 +130,11 @@ sub trySend($@)
           return 0;
     }
 
-    $server->data;
-    $server->datasend($_) foreach @header;
     my $bodydata = $message->body->file;
 
-    if(ref $bodydata eq 'GLOB') { $server->datasend($_) while <$bodydata> }
-    else    { while(my $l = $bodydata->getline) { $server->datasend($l) } }
+    $server->data;
+    $server->datasend(\@headers);
+    $server->datasend( [ ref $bodydata eq 'GLOB' ? <$bodydata> : $bodydata->getlines ] );
 
     $server->quit, return 0
         unless $server->dataend;
